@@ -33,9 +33,10 @@
 #  define CALENDARSUPPORT_DEPRECATED_NO_EXPORT CALENDARSUPPORT_NO_EXPORT CALENDARSUPPORT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define CALENDARSUPPORT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef CALENDARSUPPORT_NO_DEPRECATED
+#    define CALENDARSUPPORT_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* CALENDARSUPPORT_EXPORT_H */
